@@ -47,19 +47,29 @@
 #define CHAR_BIT		8
 #endif /* CHAR_BIT */
 
-#if !defined(TIME_T_MIN)
-#define TIME_T_MIN		((time_t)0 < (time_t)-1 ?\
-				(time_t)0 :\
-				(time_t)1 << (sizeof(time_t) * CHAR_BIT - 1))
-#endif /* TIMER_T_MIN */
+/* True if the arithmetic type T is signed.  */
+#define TYPE_SIGNED(t) (! ((t) 0 < (t) -1))
+
+/* The maximum and minimum values for the integer type T.  These
+macros have undefined behavior if T is signed and has padding bits.
+If this is a problem for you, please let us know how to fix it for
+your host.  */
+#define TYPE_MINIMUM(t) \
+((t) (! TYPE_SIGNED (t) \
+        ? (t) 0         \
+        : ~ TYPE_MAXIMUM (t)))
+#define TYPE_MAXIMUM(t)       \
+      ((t) (! TYPE_SIGNED (t) \
+              ? (t) -1        \
+              : ((((t) 1 << (sizeof (t) * CHAR_BIT - 2)) - 1) * 2 + 1)))
+
+#ifndef TIME_T_MIN
+#define TIME_T_MIN TYPE_MINIMUM (time_t)
+#endif
+#ifndef TIME_T_MAX
+#define TIME_T_MAX TYPE_MAXIMUM (time_t)
+#endif
 
-#if !defined(TIME_T_MAX)
-#if defined(__TURBOC__)	/* Turbo C chokes on the subtraction below */
-#define TIME_T_MAX		(LONG_MAX)
-#else	/* All others */
-#define TIME_T_MAX		(~(time_t)0 - TIME_T_MIN)
-#endif /* __TURBOC__ */
-#endif /* TIME_T_MAX */
 
 #if !defined(SIZE_T_MAX)
 #define SIZE_T_MAX		(~(size_t)0)
@@ -194,7 +204,7 @@
 
 
 /* Jeroen 2017: Hardcode local path */
-#define GLOBAL_ANTIWORD_DIR	"./share/antiword"
+#define GLOBAL_ANTIWORD_DIR	"../share/antiword"
 #define ANTIWORD_DIR		".antiword"
 #define FONTNAMES_FILE		"fontnames"
 
